# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SCENE_FILE_UPDATE_METADATA = Metadata(
    id="b53f9555bf7b49feaf8c70bbf947464884f01049.boutiques",
    name="scene-file-update",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SceneFileUpdateCopyMapOnePaletteParameters = typing.TypedDict('SceneFileUpdateCopyMapOnePaletteParameters', {
    "@type": typing.NotRequired[typing.Literal["copy_map_one_palette"]],
    "data_file_name_suffix": str,
})
SceneFileUpdateCopyMapOnePaletteParametersTagged = typing.TypedDict('SceneFileUpdateCopyMapOnePaletteParametersTagged', {
    "@type": typing.Literal["copy_map_one_palette"],
    "data_file_name_suffix": str,
})


SceneFileUpdateDataFileAddParameters = typing.TypedDict('SceneFileUpdateDataFileAddParameters', {
    "@type": typing.NotRequired[typing.Literal["data_file_add"]],
    "name_of_data_file": str,
})
SceneFileUpdateDataFileAddParametersTagged = typing.TypedDict('SceneFileUpdateDataFileAddParametersTagged', {
    "@type": typing.Literal["data_file_add"],
    "name_of_data_file": str,
})


SceneFileUpdateDataFileRemoveParameters = typing.TypedDict('SceneFileUpdateDataFileRemoveParameters', {
    "@type": typing.NotRequired[typing.Literal["data_file_remove"]],
    "name_of_data_file": str,
})
SceneFileUpdateDataFileRemoveParametersTagged = typing.TypedDict('SceneFileUpdateDataFileRemoveParametersTagged', {
    "@type": typing.Literal["data_file_remove"],
    "name_of_data_file": str,
})


SceneFileUpdateParameters = typing.TypedDict('SceneFileUpdateParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/scene-file-update"]],
    "input_scene_file": str,
    "output_scene_file": str,
    "scene_name_or_number": str,
    "opt_fix_map_palette_settings": bool,
    "opt_remove_missing_files": bool,
    "opt_error": bool,
    "opt_verbose": bool,
    "copy_map_one_palette": typing.NotRequired[list[SceneFileUpdateCopyMapOnePaletteParameters] | None],
    "data_file_add": typing.NotRequired[list[SceneFileUpdateDataFileAddParameters] | None],
    "data_file_remove": typing.NotRequired[list[SceneFileUpdateDataFileRemoveParameters] | None],
})
SceneFileUpdateParametersTagged = typing.TypedDict('SceneFileUpdateParametersTagged', {
    "@type": typing.Literal["workbench/scene-file-update"],
    "input_scene_file": str,
    "output_scene_file": str,
    "scene_name_or_number": str,
    "opt_fix_map_palette_settings": bool,
    "opt_remove_missing_files": bool,
    "opt_error": bool,
    "opt_verbose": bool,
    "copy_map_one_palette": typing.NotRequired[list[SceneFileUpdateCopyMapOnePaletteParameters] | None],
    "data_file_add": typing.NotRequired[list[SceneFileUpdateDataFileAddParameters] | None],
    "data_file_remove": typing.NotRequired[list[SceneFileUpdateDataFileRemoveParameters] | None],
})


def scene_file_update_copy_map_one_palette_params(
    data_file_name_suffix: str,
) -> SceneFileUpdateCopyMapOnePaletteParametersTagged:
    """
    Build parameters.
    
    Args:
        data_file_name_suffix: Name of palette mapped data file (cifti, metric,\
            volume).
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "copy_map_one_palette",
        "data_file_name_suffix": data_file_name_suffix,
    }
    return params


def scene_file_update_copy_map_one_palette_cargs(
    params: SceneFileUpdateCopyMapOnePaletteParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-copy-map-one-palette")
    cargs.append(params.get("data_file_name_suffix", None))
    return cargs


def scene_file_update_data_file_add_params(
    name_of_data_file: str,
) -> SceneFileUpdateDataFileAddParametersTagged:
    """
    Build parameters.
    
    Args:
        name_of_data_file: Name of data file. If a data file not in the current\
            directory, it is best to use an absolute path (a relative path may\
            work). Instead of a data file, this value may be the name of a text\
            file (must end in ".txt") that contains the names of one or more data\
            files, one per line.\
            Example on UNIX to create a text file containing all CIFTI scalar\
            files in the current directory with absolute paths:\
            ls -d $PWD/*dscalar.nii > file.txt.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "data_file_add",
        "name_of_data_file": name_of_data_file,
    }
    return params


def scene_file_update_data_file_add_cargs(
    params: SceneFileUpdateDataFileAddParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-data-file-add")
    cargs.append(params.get("name_of_data_file", None))
    return cargs


def scene_file_update_data_file_remove_params(
    name_of_data_file: str,
) -> SceneFileUpdateDataFileRemoveParametersTagged:
    """
    Build parameters.
    
    Args:
        name_of_data_file: Name of data file. If a data file not in the current\
            directory, it is best to use an absolute path (a relative path may\
            work). Instead of a data file, this value may be the name of a text\
            file (must end in ".txt") that contains the names of one or more data\
            files, one per line.\
            Example on UNIX to create a text file containing all CIFTI scalar\
            files in the current directory with absolute paths:\
            ls -d $PWD/*dscalar.nii > file.txt.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "data_file_remove",
        "name_of_data_file": name_of_data_file,
    }
    return params


def scene_file_update_data_file_remove_cargs(
    params: SceneFileUpdateDataFileRemoveParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-data-file-remove")
    cargs.append(params.get("name_of_data_file", None))
    return cargs


class SceneFileUpdateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SceneFileUpdateParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def scene_file_update_params(
    input_scene_file: str,
    output_scene_file: str,
    scene_name_or_number: str,
    opt_fix_map_palette_settings: bool = False,
    opt_remove_missing_files: bool = False,
    opt_error: bool = False,
    opt_verbose: bool = False,
    copy_map_one_palette: list[SceneFileUpdateCopyMapOnePaletteParameters] | None = None,
    data_file_add: list[SceneFileUpdateDataFileAddParameters] | None = None,
    data_file_remove: list[SceneFileUpdateDataFileRemoveParameters] | None = None,
) -> SceneFileUpdateParametersTagged:
    """
    Build parameters.
    
    Args:
        input_scene_file: the input scene file.
        output_scene_file: the new scene file to create.
        scene_name_or_number: name or number (starting at one) of the scene in\
            the scene file.
        opt_fix_map_palette_settings: Fix palette settings for files with\
            change in number of maps.
        opt_remove_missing_files: Remove missing files from SpecFile.
        opt_error: Abort command if there is an error performing any of the\
            operations on the scene file.
        opt_verbose: Print names of files that have palettes updated.
        copy_map_one_palette: Copy palettes settings from first map to all maps\
            in a data file.
        data_file_add: Add a data file to scene's loaded files.
        data_file_remove: Remove a data file from scene's loaded files.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/scene-file-update",
        "input_scene_file": input_scene_file,
        "output_scene_file": output_scene_file,
        "scene_name_or_number": scene_name_or_number,
        "opt_fix_map_palette_settings": opt_fix_map_palette_settings,
        "opt_remove_missing_files": opt_remove_missing_files,
        "opt_error": opt_error,
        "opt_verbose": opt_verbose,
    }
    if copy_map_one_palette is not None:
        params["copy_map_one_palette"] = copy_map_one_palette
    if data_file_add is not None:
        params["data_file_add"] = data_file_add
    if data_file_remove is not None:
        params["data_file_remove"] = data_file_remove
    return params


def scene_file_update_cargs(
    params: SceneFileUpdateParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-scene-file-update")
    cargs.append(params.get("input_scene_file", None))
    cargs.append(params.get("output_scene_file", None))
    cargs.append(params.get("scene_name_or_number", None))
    if params.get("opt_fix_map_palette_settings", False):
        cargs.append("-fix-map-palette-settings")
    if params.get("opt_remove_missing_files", False):
        cargs.append("-remove-missing-files")
    if params.get("opt_error", False):
        cargs.append("-error")
    if params.get("opt_verbose", False):
        cargs.append("-verbose")
    if params.get("copy_map_one_palette", None) is not None:
        cargs.extend([a for c in [scene_file_update_copy_map_one_palette_cargs(s, execution) for s in params.get("copy_map_one_palette", None)] for a in c])
    if params.get("data_file_add", None) is not None:
        cargs.extend([a for c in [scene_file_update_data_file_add_cargs(s, execution) for s in params.get("data_file_add", None)] for a in c])
    if params.get("data_file_remove", None) is not None:
        cargs.extend([a for c in [scene_file_update_data_file_remove_cargs(s, execution) for s in params.get("data_file_remove", None)] for a in c])
    return cargs


def scene_file_update_outputs(
    params: SceneFileUpdateParameters,
    execution: Execution,
) -> SceneFileUpdateOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SceneFileUpdateOutputs(
        root=execution.output_file("."),
    )
    return ret


def scene_file_update_execute(
    params: SceneFileUpdateParameters,
    runner: Runner | None = None,
) -> SceneFileUpdateOutputs:
    """
    scene-file-update
    
    Update scene file.
    
    This command will update a scene for specific changes in data files.
    
    "-fix-map-palette-settings" will find all data files that have had a change
    in the number of maps since the scene scene was created. If the file has its
    "Apply to All Maps" property enabled, the palette setting in the first map
    is copied to all maps in the file. Note: This modifies the palette settings
    for the file in the scene (data file is NOT modified).
    
    "-copy-map-one-palette" will copy the palette settings from the first map to
    all other maps in a data file. This option is typically used when the number
    of maps in a data file changes. It changes the palette settings in the scene
    that are applied to the data file when the scene is loaded (the data file is
    not modified). The name of the data file specified on the command line is
    matched to the end of file names in the scene. This allows matching multiple
    files if their names end with the same characters. It also allows including
    a relative path when there is more than one file with the same name but in
    different paths and only one of the files to be updated.
    
    "-remove-missing-files" Any files that fail to load when the scene is read
    will be removed from the scene. Thus, if one deletes files prior to running
    with this option, the deleted files are removed from the scene.
    
    "-error" If this option is provided and there is an error while performing
    any of the scene operations, the command will immediately cease processing
    and the output scene file will not be created. Otherwise any errors will be
    listed after the command finishes.
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SceneFileUpdateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SCENE_FILE_UPDATE_METADATA)
    params = execution.params(params)
    cargs = scene_file_update_cargs(params, execution)
    ret = scene_file_update_outputs(params, execution)
    execution.run(cargs)
    return ret


def scene_file_update(
    input_scene_file: str,
    output_scene_file: str,
    scene_name_or_number: str,
    opt_fix_map_palette_settings: bool = False,
    opt_remove_missing_files: bool = False,
    opt_error: bool = False,
    opt_verbose: bool = False,
    copy_map_one_palette: list[SceneFileUpdateCopyMapOnePaletteParameters] | None = None,
    data_file_add: list[SceneFileUpdateDataFileAddParameters] | None = None,
    data_file_remove: list[SceneFileUpdateDataFileRemoveParameters] | None = None,
    runner: Runner | None = None,
) -> SceneFileUpdateOutputs:
    """
    scene-file-update
    
    Update scene file.
    
    This command will update a scene for specific changes in data files.
    
    "-fix-map-palette-settings" will find all data files that have had a change
    in the number of maps since the scene scene was created. If the file has its
    "Apply to All Maps" property enabled, the palette setting in the first map
    is copied to all maps in the file. Note: This modifies the palette settings
    for the file in the scene (data file is NOT modified).
    
    "-copy-map-one-palette" will copy the palette settings from the first map to
    all other maps in a data file. This option is typically used when the number
    of maps in a data file changes. It changes the palette settings in the scene
    that are applied to the data file when the scene is loaded (the data file is
    not modified). The name of the data file specified on the command line is
    matched to the end of file names in the scene. This allows matching multiple
    files if their names end with the same characters. It also allows including
    a relative path when there is more than one file with the same name but in
    different paths and only one of the files to be updated.
    
    "-remove-missing-files" Any files that fail to load when the scene is read
    will be removed from the scene. Thus, if one deletes files prior to running
    with this option, the deleted files are removed from the scene.
    
    "-error" If this option is provided and there is an error while performing
    any of the scene operations, the command will immediately cease processing
    and the output scene file will not be created. Otherwise any errors will be
    listed after the command finishes.
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        input_scene_file: the input scene file.
        output_scene_file: the new scene file to create.
        scene_name_or_number: name or number (starting at one) of the scene in\
            the scene file.
        opt_fix_map_palette_settings: Fix palette settings for files with\
            change in number of maps.
        opt_remove_missing_files: Remove missing files from SpecFile.
        opt_error: Abort command if there is an error performing any of the\
            operations on the scene file.
        opt_verbose: Print names of files that have palettes updated.
        copy_map_one_palette: Copy palettes settings from first map to all maps\
            in a data file.
        data_file_add: Add a data file to scene's loaded files.
        data_file_remove: Remove a data file from scene's loaded files.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SceneFileUpdateOutputs`).
    """
    params = scene_file_update_params(
        input_scene_file=input_scene_file,
        output_scene_file=output_scene_file,
        scene_name_or_number=scene_name_or_number,
        opt_fix_map_palette_settings=opt_fix_map_palette_settings,
        opt_remove_missing_files=opt_remove_missing_files,
        opt_error=opt_error,
        opt_verbose=opt_verbose,
        copy_map_one_palette=copy_map_one_palette,
        data_file_add=data_file_add,
        data_file_remove=data_file_remove,
    )
    return scene_file_update_execute(params, runner)


__all__ = [
    "SCENE_FILE_UPDATE_METADATA",
    "SceneFileUpdateOutputs",
    "scene_file_update",
    "scene_file_update_copy_map_one_palette_params",
    "scene_file_update_data_file_add_params",
    "scene_file_update_data_file_remove_params",
    "scene_file_update_execute",
    "scene_file_update_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_MERGE_PARCELS_METADATA = Metadata(
    id="6843c1951c4ae4950f7c0694f8574395469f0819.boutiques",
    name="cifti-merge-parcels",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiMergeParcelsCiftiParameters = typing.TypedDict('CiftiMergeParcelsCiftiParameters', {
    "@type": typing.NotRequired[typing.Literal["cifti"]],
    "cifti_in": InputPathType,
})
CiftiMergeParcelsCiftiParametersTagged = typing.TypedDict('CiftiMergeParcelsCiftiParametersTagged', {
    "@type": typing.Literal["cifti"],
    "cifti_in": InputPathType,
})


CiftiMergeParcelsParameters = typing.TypedDict('CiftiMergeParcelsParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-merge-parcels"]],
    "direction": str,
    "cifti_out": str,
    "cifti": typing.NotRequired[list[CiftiMergeParcelsCiftiParameters] | None],
})
CiftiMergeParcelsParametersTagged = typing.TypedDict('CiftiMergeParcelsParametersTagged', {
    "@type": typing.Literal["workbench/cifti-merge-parcels"],
    "direction": str,
    "cifti_out": str,
    "cifti": typing.NotRequired[list[CiftiMergeParcelsCiftiParameters] | None],
})


def cifti_merge_parcels_cifti_params(
    cifti_in: InputPathType,
) -> CiftiMergeParcelsCiftiParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti_in: a cifti file to merge.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "cifti",
        "cifti_in": cifti_in,
    }
    return params


def cifti_merge_parcels_cifti_cargs(
    params: CiftiMergeParcelsCiftiParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-cifti")
    cargs.append(execution.input_file(params.get("cifti_in", None)))
    return cargs


class CiftiMergeParcelsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiMergeParcelsParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti file"""


def cifti_merge_parcels_params(
    direction: str,
    cifti_out: str,
    cifti: list[CiftiMergeParcelsCiftiParameters] | None = None,
) -> CiftiMergeParcelsParametersTagged:
    """
    Build parameters.
    
    Args:
        direction: which dimension to merge along (integer, 'ROW', or 'COLUMN').
        cifti_out: the output cifti file.
        cifti: specify an input cifti file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-merge-parcels",
        "direction": direction,
        "cifti_out": cifti_out,
    }
    if cifti is not None:
        params["cifti"] = cifti
    return params


def cifti_merge_parcels_cargs(
    params: CiftiMergeParcelsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-merge-parcels")
    cargs.append(params.get("direction", None))
    cargs.append(params.get("cifti_out", None))
    if params.get("cifti", None) is not None:
        cargs.extend([a for c in [cifti_merge_parcels_cifti_cargs(s, execution) for s in params.get("cifti", None)] for a in c])
    return cargs


def cifti_merge_parcels_outputs(
    params: CiftiMergeParcelsParameters,
    execution: Execution,
) -> CiftiMergeParcelsOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiMergeParcelsOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(params.get("cifti_out", None)),
    )
    return ret


def cifti_merge_parcels_execute(
    params: CiftiMergeParcelsParameters,
    runner: Runner | None = None,
) -> CiftiMergeParcelsOutputs:
    """
    cifti-merge-parcels
    
    Merge cifti files along parcels dimension.
    
    The input cifti files must have matching mappings along the direction not
    specified, and the mapping along the specified direction must be parcels.
    The direction can be either an integer starting from 1, or the strings 'ROW'
    or 'COLUMN'.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiMergeParcelsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_MERGE_PARCELS_METADATA)
    params = execution.params(params)
    cargs = cifti_merge_parcels_cargs(params, execution)
    ret = cifti_merge_parcels_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_merge_parcels(
    direction: str,
    cifti_out: str,
    cifti: list[CiftiMergeParcelsCiftiParameters] | None = None,
    runner: Runner | None = None,
) -> CiftiMergeParcelsOutputs:
    """
    cifti-merge-parcels
    
    Merge cifti files along parcels dimension.
    
    The input cifti files must have matching mappings along the direction not
    specified, and the mapping along the specified direction must be parcels.
    The direction can be either an integer starting from 1, or the strings 'ROW'
    or 'COLUMN'.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        direction: which dimension to merge along (integer, 'ROW', or 'COLUMN').
        cifti_out: the output cifti file.
        cifti: specify an input cifti file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiMergeParcelsOutputs`).
    """
    params = cifti_merge_parcels_params(
        direction=direction,
        cifti_out=cifti_out,
        cifti=cifti,
    )
    return cifti_merge_parcels_execute(params, runner)


__all__ = [
    "CIFTI_MERGE_PARCELS_METADATA",
    "CiftiMergeParcelsOutputs",
    "cifti_merge_parcels",
    "cifti_merge_parcels_cifti_params",
    "cifti_merge_parcels_execute",
    "cifti_merge_parcels_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

VOLUME_CREATE_METADATA = Metadata(
    id="4f88aa095b5dfcbd90372ec9ac43f92934dd4cba.boutiques",
    name="volume-create",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


VolumeCreatePlumbParameters = typing.TypedDict('VolumeCreatePlumbParameters', {
    "@type": typing.NotRequired[typing.Literal["plumb"]],
    "axis_order": str,
    "x_spacing": float,
    "y_spacing": float,
    "z_spacing": float,
    "x_offset": float,
    "y_offset": float,
    "z_offset": float,
})
VolumeCreatePlumbParametersTagged = typing.TypedDict('VolumeCreatePlumbParametersTagged', {
    "@type": typing.Literal["plumb"],
    "axis_order": str,
    "x_spacing": float,
    "y_spacing": float,
    "z_spacing": float,
    "x_offset": float,
    "y_offset": float,
    "z_offset": float,
})


VolumeCreateSformParameters = typing.TypedDict('VolumeCreateSformParameters', {
    "@type": typing.NotRequired[typing.Literal["sform"]],
    "xi_spacing": float,
    "xj_spacing": float,
    "xk_spacing": float,
    "x_offset": float,
    "yi_spacing": float,
    "yj_spacing": float,
    "yk_spacing": float,
    "y_offset": float,
    "zi_spacing": float,
    "zj_spacing": float,
    "zk_spacing": float,
    "z_offset": float,
})
VolumeCreateSformParametersTagged = typing.TypedDict('VolumeCreateSformParametersTagged', {
    "@type": typing.Literal["sform"],
    "xi_spacing": float,
    "xj_spacing": float,
    "xk_spacing": float,
    "x_offset": float,
    "yi_spacing": float,
    "yj_spacing": float,
    "yk_spacing": float,
    "y_offset": float,
    "zi_spacing": float,
    "zj_spacing": float,
    "zk_spacing": float,
    "z_offset": float,
})


VolumeCreateParameters = typing.TypedDict('VolumeCreateParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/volume-create"]],
    "i_dim": int,
    "j_dim": int,
    "k_dim": int,
    "volume_out": str,
    "plumb": typing.NotRequired[VolumeCreatePlumbParameters | None],
    "sform": typing.NotRequired[VolumeCreateSformParameters | None],
})
VolumeCreateParametersTagged = typing.TypedDict('VolumeCreateParametersTagged', {
    "@type": typing.Literal["workbench/volume-create"],
    "i_dim": int,
    "j_dim": int,
    "k_dim": int,
    "volume_out": str,
    "plumb": typing.NotRequired[VolumeCreatePlumbParameters | None],
    "sform": typing.NotRequired[VolumeCreateSformParameters | None],
})


def volume_create_plumb_params(
    axis_order: str,
    x_spacing: float,
    y_spacing: float,
    z_spacing: float,
    x_offset: float,
    y_offset: float,
    z_offset: float,
) -> VolumeCreatePlumbParametersTagged:
    """
    Build parameters.
    
    Args:
        axis_order: a string like 'XYZ' that specifies which index is along\
            which spatial dimension.
        x_spacing: change in x-coordinate from incrementing the relevant index.
        y_spacing: change in y-coordinate from incrementing the relevant index.
        z_spacing: change in z-coordinate from incrementing the relevant index.
        x_offset: the x-coordinate of the center of the first voxel.
        y_offset: the y-coordinate of the center of the first voxel.
        z_offset: the z-coordinate of the center of the first voxel.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "plumb",
        "axis_order": axis_order,
        "x_spacing": x_spacing,
        "y_spacing": y_spacing,
        "z_spacing": z_spacing,
        "x_offset": x_offset,
        "y_offset": y_offset,
        "z_offset": z_offset,
    }
    return params


def volume_create_plumb_cargs(
    params: VolumeCreatePlumbParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-plumb")
    cargs.append(params.get("axis_order", None))
    cargs.append(str(params.get("x_spacing", None)))
    cargs.append(str(params.get("y_spacing", None)))
    cargs.append(str(params.get("z_spacing", None)))
    cargs.append(str(params.get("x_offset", None)))
    cargs.append(str(params.get("y_offset", None)))
    cargs.append(str(params.get("z_offset", None)))
    return cargs


def volume_create_sform_params(
    xi_spacing: float,
    xj_spacing: float,
    xk_spacing: float,
    x_offset: float,
    yi_spacing: float,
    yj_spacing: float,
    yk_spacing: float,
    y_offset: float,
    zi_spacing: float,
    zj_spacing: float,
    zk_spacing: float,
    z_offset: float,
) -> VolumeCreateSformParametersTagged:
    """
    Build parameters.
    
    Args:
        xi_spacing: increase in x coordinate from incrementing the i index.
        xj_spacing: increase in x coordinate from incrementing the j index.
        xk_spacing: increase in x coordinate from incrementing the k index.
        x_offset: x coordinate of first voxel.
        yi_spacing: increase in y coordinate from incrementing the i index.
        yj_spacing: increase in y coordinate from incrementing the j index.
        yk_spacing: increase in y coordinate from incrementing the k index.
        y_offset: y coordinate of first voxel.
        zi_spacing: increase in z coordinate from incrementing the i index.
        zj_spacing: increase in z coordinate from incrementing the j index.
        zk_spacing: increase in z coordinate from incrementing the k index.
        z_offset: z coordinate of first voxel.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "sform",
        "xi_spacing": xi_spacing,
        "xj_spacing": xj_spacing,
        "xk_spacing": xk_spacing,
        "x_offset": x_offset,
        "yi_spacing": yi_spacing,
        "yj_spacing": yj_spacing,
        "yk_spacing": yk_spacing,
        "y_offset": y_offset,
        "zi_spacing": zi_spacing,
        "zj_spacing": zj_spacing,
        "zk_spacing": zk_spacing,
        "z_offset": z_offset,
    }
    return params


def volume_create_sform_cargs(
    params: VolumeCreateSformParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-sform")
    cargs.append(str(params.get("xi_spacing", None)))
    cargs.append(str(params.get("xj_spacing", None)))
    cargs.append(str(params.get("xk_spacing", None)))
    cargs.append(str(params.get("x_offset", None)))
    cargs.append(str(params.get("yi_spacing", None)))
    cargs.append(str(params.get("yj_spacing", None)))
    cargs.append(str(params.get("yk_spacing", None)))
    cargs.append(str(params.get("y_offset", None)))
    cargs.append(str(params.get("zi_spacing", None)))
    cargs.append(str(params.get("zj_spacing", None)))
    cargs.append(str(params.get("zk_spacing", None)))
    cargs.append(str(params.get("z_offset", None)))
    return cargs


class VolumeCreateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `VolumeCreateParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output volume"""


def volume_create_params(
    i_dim: int,
    j_dim: int,
    k_dim: int,
    volume_out: str,
    plumb: VolumeCreatePlumbParameters | None = None,
    sform: VolumeCreateSformParameters | None = None,
) -> VolumeCreateParametersTagged:
    """
    Build parameters.
    
    Args:
        i_dim: length of first dimension.
        j_dim: length of second dimension.
        k_dim: length of third dimension.
        volume_out: the output volume.
        plumb: set via axis order and spacing/offset.
        sform: set via a nifti sform.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/volume-create",
        "i_dim": i_dim,
        "j_dim": j_dim,
        "k_dim": k_dim,
        "volume_out": volume_out,
    }
    if plumb is not None:
        params["plumb"] = plumb
    if sform is not None:
        params["sform"] = sform
    return params


def volume_create_cargs(
    params: VolumeCreateParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-create")
    cargs.append(str(params.get("i_dim", None)))
    cargs.append(str(params.get("j_dim", None)))
    cargs.append(str(params.get("k_dim", None)))
    cargs.append(params.get("volume_out", None))
    if params.get("plumb", None) is not None:
        cargs.extend(volume_create_plumb_cargs(params.get("plumb", None), execution))
    if params.get("sform", None) is not None:
        cargs.extend(volume_create_sform_cargs(params.get("sform", None), execution))
    return cargs


def volume_create_outputs(
    params: VolumeCreateParameters,
    execution: Execution,
) -> VolumeCreateOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = VolumeCreateOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(params.get("volume_out", None)),
    )
    return ret


def volume_create_execute(
    params: VolumeCreateParameters,
    runner: Runner | None = None,
) -> VolumeCreateOutputs:
    """
    volume-create
    
    Create a blank volume file.
    
    Creates a volume file full of zeros. Exactly one of -plumb or -sform must be
    specified.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeCreateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_CREATE_METADATA)
    params = execution.params(params)
    cargs = volume_create_cargs(params, execution)
    ret = volume_create_outputs(params, execution)
    execution.run(cargs)
    return ret


def volume_create(
    i_dim: int,
    j_dim: int,
    k_dim: int,
    volume_out: str,
    plumb: VolumeCreatePlumbParameters | None = None,
    sform: VolumeCreateSformParameters | None = None,
    runner: Runner | None = None,
) -> VolumeCreateOutputs:
    """
    volume-create
    
    Create a blank volume file.
    
    Creates a volume file full of zeros. Exactly one of -plumb or -sform must be
    specified.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        i_dim: length of first dimension.
        j_dim: length of second dimension.
        k_dim: length of third dimension.
        volume_out: the output volume.
        plumb: set via axis order and spacing/offset.
        sform: set via a nifti sform.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeCreateOutputs`).
    """
    params = volume_create_params(
        i_dim=i_dim,
        j_dim=j_dim,
        k_dim=k_dim,
        volume_out=volume_out,
        plumb=plumb,
        sform=sform,
    )
    return volume_create_execute(params, runner)


__all__ = [
    "VOLUME_CREATE_METADATA",
    "VolumeCreateOutputs",
    "volume_create",
    "volume_create_execute",
    "volume_create_params",
    "volume_create_plumb_params",
    "volume_create_sform_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_CORRELATION_METADATA = Metadata(
    id="af245290fbe6593faa46f40cb576c436c697b361.boutiques",
    name="cifti-correlation",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiCorrelationRoiOverrideParameters = typing.TypedDict('CiftiCorrelationRoiOverrideParameters', {
    "@type": typing.NotRequired[typing.Literal["roi_override"]],
    "opt_left_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_right_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_cerebellum_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_vol_roi_roi_vol": typing.NotRequired[InputPathType | None],
    "opt_cifti_roi_roi_cifti": typing.NotRequired[InputPathType | None],
})
CiftiCorrelationRoiOverrideParametersTagged = typing.TypedDict('CiftiCorrelationRoiOverrideParametersTagged', {
    "@type": typing.Literal["roi_override"],
    "opt_left_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_right_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_cerebellum_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_vol_roi_roi_vol": typing.NotRequired[InputPathType | None],
    "opt_cifti_roi_roi_cifti": typing.NotRequired[InputPathType | None],
})


CiftiCorrelationParameters = typing.TypedDict('CiftiCorrelationParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-correlation"]],
    "cifti": InputPathType,
    "cifti_out": str,
    "roi_override": typing.NotRequired[CiftiCorrelationRoiOverrideParameters | None],
    "opt_weights_weight_file": typing.NotRequired[str | None],
    "opt_fisher_z": bool,
    "opt_no_demean": bool,
    "opt_covariance": bool,
    "opt_mem_limit_limit_gb": typing.NotRequired[float | None],
})
CiftiCorrelationParametersTagged = typing.TypedDict('CiftiCorrelationParametersTagged', {
    "@type": typing.Literal["workbench/cifti-correlation"],
    "cifti": InputPathType,
    "cifti_out": str,
    "roi_override": typing.NotRequired[CiftiCorrelationRoiOverrideParameters | None],
    "opt_weights_weight_file": typing.NotRequired[str | None],
    "opt_fisher_z": bool,
    "opt_no_demean": bool,
    "opt_covariance": bool,
    "opt_mem_limit_limit_gb": typing.NotRequired[float | None],
})


def cifti_correlation_roi_override_params(
    opt_left_roi_roi_metric: InputPathType | None = None,
    opt_right_roi_roi_metric: InputPathType | None = None,
    opt_cerebellum_roi_roi_metric: InputPathType | None = None,
    opt_vol_roi_roi_vol: InputPathType | None = None,
    opt_cifti_roi_roi_cifti: InputPathType | None = None,
) -> CiftiCorrelationRoiOverrideParametersTagged:
    """
    Build parameters.
    
    Args:
        opt_left_roi_roi_metric: use an roi for left hempsphere: the left roi\
            as a metric file.
        opt_right_roi_roi_metric: use an roi for right hempsphere: the right\
            roi as a metric file.
        opt_cerebellum_roi_roi_metric: use an roi for cerebellum: the\
            cerebellum roi as a metric file.
        opt_vol_roi_roi_vol: use an roi for volume: the volume roi file.
        opt_cifti_roi_roi_cifti: use a cifti file for combined rois: the cifti\
            roi file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "roi_override",
    }
    if opt_left_roi_roi_metric is not None:
        params["opt_left_roi_roi_metric"] = opt_left_roi_roi_metric
    if opt_right_roi_roi_metric is not None:
        params["opt_right_roi_roi_metric"] = opt_right_roi_roi_metric
    if opt_cerebellum_roi_roi_metric is not None:
        params["opt_cerebellum_roi_roi_metric"] = opt_cerebellum_roi_roi_metric
    if opt_vol_roi_roi_vol is not None:
        params["opt_vol_roi_roi_vol"] = opt_vol_roi_roi_vol
    if opt_cifti_roi_roi_cifti is not None:
        params["opt_cifti_roi_roi_cifti"] = opt_cifti_roi_roi_cifti
    return params


def cifti_correlation_roi_override_cargs(
    params: CiftiCorrelationRoiOverrideParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-roi-override")
    if params.get("opt_left_roi_roi_metric", None) is not None:
        cargs.extend([
            "-left-roi",
            execution.input_file(params.get("opt_left_roi_roi_metric", None))
        ])
    if params.get("opt_right_roi_roi_metric", None) is not None:
        cargs.extend([
            "-right-roi",
            execution.input_file(params.get("opt_right_roi_roi_metric", None))
        ])
    if params.get("opt_cerebellum_roi_roi_metric", None) is not None:
        cargs.extend([
            "-cerebellum-roi",
            execution.input_file(params.get("opt_cerebellum_roi_roi_metric", None))
        ])
    if params.get("opt_vol_roi_roi_vol", None) is not None:
        cargs.extend([
            "-vol-roi",
            execution.input_file(params.get("opt_vol_roi_roi_vol", None))
        ])
    if params.get("opt_cifti_roi_roi_cifti", None) is not None:
        cargs.extend([
            "-cifti-roi",
            execution.input_file(params.get("opt_cifti_roi_roi_cifti", None))
        ])
    return cargs


class CiftiCorrelationOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiCorrelationParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """output cifti file"""


def cifti_correlation_params(
    cifti: InputPathType,
    cifti_out: str,
    roi_override: CiftiCorrelationRoiOverrideParameters | None = None,
    opt_weights_weight_file: str | None = None,
    opt_fisher_z: bool = False,
    opt_no_demean: bool = False,
    opt_covariance: bool = False,
    opt_mem_limit_limit_gb: float | None = None,
) -> CiftiCorrelationParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti: input cifti file.
        cifti_out: output cifti file.
        roi_override: perform correlation from a subset of rows to all rows.
        opt_weights_weight_file: specify column weights: text file containing\
            one weight per column.
        opt_fisher_z: apply fisher small z transform (ie, artanh) to\
            correlation.
        opt_no_demean: instead of correlation, do dot product of rows, then\
            normalize by diagonal.
        opt_covariance: compute covariance instead of correlation.
        opt_mem_limit_limit_gb: restrict memory usage: memory limit in\
            gigabytes.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-correlation",
        "cifti": cifti,
        "cifti_out": cifti_out,
        "opt_fisher_z": opt_fisher_z,
        "opt_no_demean": opt_no_demean,
        "opt_covariance": opt_covariance,
    }
    if roi_override is not None:
        params["roi_override"] = roi_override
    if opt_weights_weight_file is not None:
        params["opt_weights_weight_file"] = opt_weights_weight_file
    if opt_mem_limit_limit_gb is not None:
        params["opt_mem_limit_limit_gb"] = opt_mem_limit_limit_gb
    return params


def cifti_correlation_cargs(
    params: CiftiCorrelationParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-correlation")
    cargs.append(execution.input_file(params.get("cifti", None)))
    cargs.append(params.get("cifti_out", None))
    if params.get("roi_override", None) is not None:
        cargs.extend(cifti_correlation_roi_override_cargs(params.get("roi_override", None), execution))
    if params.get("opt_weights_weight_file", None) is not None:
        cargs.extend([
            "-weights",
            params.get("opt_weights_weight_file", None)
        ])
    if params.get("opt_fisher_z", False):
        cargs.append("-fisher-z")
    if params.get("opt_no_demean", False):
        cargs.append("-no-demean")
    if params.get("opt_covariance", False):
        cargs.append("-covariance")
    if params.get("opt_mem_limit_limit_gb", None) is not None:
        cargs.extend([
            "-mem-limit",
            str(params.get("opt_mem_limit_limit_gb", None))
        ])
    return cargs


def cifti_correlation_outputs(
    params: CiftiCorrelationParameters,
    execution: Execution,
) -> CiftiCorrelationOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiCorrelationOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(params.get("cifti_out", None)),
    )
    return ret


def cifti_correlation_execute(
    params: CiftiCorrelationParameters,
    runner: Runner | None = None,
) -> CiftiCorrelationOutputs:
    """
    cifti-correlation
    
    Generate correlation of rows in a cifti file.
    
    For each row (or each row inside an roi if -roi-override is specified),
    correlate to all other rows. The -cifti-roi suboption to -roi-override may
    not be specified with any other -*-roi suboption, but you may specify the
    other -*-roi suboptions together.
    
    When using the -fisher-z option, the output is NOT a Z-score, it is
    artanh(r), to do further math on this output, consider using -cifti-math.
    
    Restricting the memory usage will make it calculate the output in chunks,
    and if the input file size is more than 70% of the memory limit, it will
    also read through the input file as rows are required, resulting in several
    passes through the input file (once per chunk). Memory limit does not need
    to be an integer, you may also specify 0 to calculate a single output row at
    a time (this may be very slow).
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiCorrelationOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_CORRELATION_METADATA)
    params = execution.params(params)
    cargs = cifti_correlation_cargs(params, execution)
    ret = cifti_correlation_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_correlation(
    cifti: InputPathType,
    cifti_out: str,
    roi_override: CiftiCorrelationRoiOverrideParameters | None = None,
    opt_weights_weight_file: str | None = None,
    opt_fisher_z: bool = False,
    opt_no_demean: bool = False,
    opt_covariance: bool = False,
    opt_mem_limit_limit_gb: float | None = None,
    runner: Runner | None = None,
) -> CiftiCorrelationOutputs:
    """
    cifti-correlation
    
    Generate correlation of rows in a cifti file.
    
    For each row (or each row inside an roi if -roi-override is specified),
    correlate to all other rows. The -cifti-roi suboption to -roi-override may
    not be specified with any other -*-roi suboption, but you may specify the
    other -*-roi suboptions together.
    
    When using the -fisher-z option, the output is NOT a Z-score, it is
    artanh(r), to do further math on this output, consider using -cifti-math.
    
    Restricting the memory usage will make it calculate the output in chunks,
    and if the input file size is more than 70% of the memory limit, it will
    also read through the input file as rows are required, resulting in several
    passes through the input file (once per chunk). Memory limit does not need
    to be an integer, you may also specify 0 to calculate a single output row at
    a time (this may be very slow).
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti: input cifti file.
        cifti_out: output cifti file.
        roi_override: perform correlation from a subset of rows to all rows.
        opt_weights_weight_file: specify column weights: text file containing\
            one weight per column.
        opt_fisher_z: apply fisher small z transform (ie, artanh) to\
            correlation.
        opt_no_demean: instead of correlation, do dot product of rows, then\
            normalize by diagonal.
        opt_covariance: compute covariance instead of correlation.
        opt_mem_limit_limit_gb: restrict memory usage: memory limit in\
            gigabytes.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiCorrelationOutputs`).
    """
    params = cifti_correlation_params(
        cifti=cifti,
        cifti_out=cifti_out,
        roi_override=roi_override,
        opt_weights_weight_file=opt_weights_weight_file,
        opt_fisher_z=opt_fisher_z,
        opt_no_demean=opt_no_demean,
        opt_covariance=opt_covariance,
        opt_mem_limit_limit_gb=opt_mem_limit_limit_gb,
    )
    return cifti_correlation_execute(params, runner)


__all__ = [
    "CIFTI_CORRELATION_METADATA",
    "CiftiCorrelationOutputs",
    "cifti_correlation",
    "cifti_correlation_execute",
    "cifti_correlation_params",
    "cifti_correlation_roi_override_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

VOLUME_COMPONENTS_TO_FRAMES_METADATA = Metadata(
    id="4b760afd4bd4e051700d48a7777f581e94a58d40.boutiques",
    name="volume-components-to-frames",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


VolumeComponentsToFramesParameters = typing.TypedDict('VolumeComponentsToFramesParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/volume-components-to-frames"]],
    "input": InputPathType,
    "output": str,
})
VolumeComponentsToFramesParametersTagged = typing.TypedDict('VolumeComponentsToFramesParametersTagged', {
    "@type": typing.Literal["workbench/volume-components-to-frames"],
    "input": InputPathType,
    "output": str,
})


class VolumeComponentsToFramesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `VolumeComponentsToFramesParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """the input volume converted to multiple frames of scalar type"""


def volume_components_to_frames_params(
    input_: InputPathType,
    output: str,
) -> VolumeComponentsToFramesParametersTagged:
    """
    Build parameters.
    
    Args:
        input_: the RGB/complex-type volume.
        output: the input volume converted to multiple frames of scalar type.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/volume-components-to-frames",
        "input": input_,
        "output": output,
    }
    return params


def volume_components_to_frames_cargs(
    params: VolumeComponentsToFramesParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-components-to-frames")
    cargs.append(execution.input_file(params.get("input", None)))
    cargs.append(params.get("output", None))
    return cargs


def volume_components_to_frames_outputs(
    params: VolumeComponentsToFramesParameters,
    execution: Execution,
) -> VolumeComponentsToFramesOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = VolumeComponentsToFramesOutputs(
        root=execution.output_file("."),
        output=execution.output_file(params.get("output", None)),
    )
    return ret


def volume_components_to_frames_execute(
    params: VolumeComponentsToFramesParameters,
    runner: Runner | None = None,
) -> VolumeComponentsToFramesOutputs:
    """
    volume-components-to-frames
    
    Convert rgb/complex volume to frames.
    
    RGB and complex datatypes are not always well supported, this command allows
    separating them into standard subvolumes for better support.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeComponentsToFramesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_COMPONENTS_TO_FRAMES_METADATA)
    params = execution.params(params)
    cargs = volume_components_to_frames_cargs(params, execution)
    ret = volume_components_to_frames_outputs(params, execution)
    execution.run(cargs)
    return ret


def volume_components_to_frames(
    input_: InputPathType,
    output: str,
    runner: Runner | None = None,
) -> VolumeComponentsToFramesOutputs:
    """
    volume-components-to-frames
    
    Convert rgb/complex volume to frames.
    
    RGB and complex datatypes are not always well supported, this command allows
    separating them into standard subvolumes for better support.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        input_: the RGB/complex-type volume.
        output: the input volume converted to multiple frames of scalar type.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeComponentsToFramesOutputs`).
    """
    params = volume_components_to_frames_params(
        input_=input_,
        output=output,
    )
    return volume_components_to_frames_execute(params, runner)


__all__ = [
    "VOLUME_COMPONENTS_TO_FRAMES_METADATA",
    "VolumeComponentsToFramesOutputs",
    "volume_components_to_frames",
    "volume_components_to_frames_execute",
    "volume_components_to_frames_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

BORDER_MERGE_METADATA = Metadata(
    id="7be2470075824ac407debd55d81755eb8f1ddd15.boutiques",
    name="border-merge",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


BorderMergeUpToParameters = typing.TypedDict('BorderMergeUpToParameters', {
    "@type": typing.NotRequired[typing.Literal["up_to"]],
    "last_border": str,
    "opt_reverse": bool,
})
BorderMergeUpToParametersTagged = typing.TypedDict('BorderMergeUpToParametersTagged', {
    "@type": typing.Literal["up_to"],
    "last_border": str,
    "opt_reverse": bool,
})


BorderMergeSelectParameters = typing.TypedDict('BorderMergeSelectParameters', {
    "@type": typing.NotRequired[typing.Literal["select"]],
    "border": str,
    "up_to": typing.NotRequired[BorderMergeUpToParameters | None],
})
BorderMergeSelectParametersTagged = typing.TypedDict('BorderMergeSelectParametersTagged', {
    "@type": typing.Literal["select"],
    "border": str,
    "up_to": typing.NotRequired[BorderMergeUpToParameters | None],
})


BorderMergeBorderParameters = typing.TypedDict('BorderMergeBorderParameters', {
    "@type": typing.NotRequired[typing.Literal["border"]],
    "border_file_in": InputPathType,
    "select": typing.NotRequired[list[BorderMergeSelectParameters] | None],
})
BorderMergeBorderParametersTagged = typing.TypedDict('BorderMergeBorderParametersTagged', {
    "@type": typing.Literal["border"],
    "border_file_in": InputPathType,
    "select": typing.NotRequired[list[BorderMergeSelectParameters] | None],
})


BorderMergeParameters = typing.TypedDict('BorderMergeParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/border-merge"]],
    "border_file_out": str,
    "border": typing.NotRequired[list[BorderMergeBorderParameters] | None],
})
BorderMergeParametersTagged = typing.TypedDict('BorderMergeParametersTagged', {
    "@type": typing.Literal["workbench/border-merge"],
    "border_file_out": str,
    "border": typing.NotRequired[list[BorderMergeBorderParameters] | None],
})


def border_merge_up_to_params(
    last_border: str,
    opt_reverse: bool = False,
) -> BorderMergeUpToParametersTagged:
    """
    Build parameters.
    
    Args:
        last_border: the number or name of the last column to include.
        opt_reverse: use the range in reverse order.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "up_to",
        "last_border": last_border,
        "opt_reverse": opt_reverse,
    }
    return params


def border_merge_up_to_cargs(
    params: BorderMergeUpToParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-up-to")
    cargs.append(params.get("last_border", None))
    if params.get("opt_reverse", False):
        cargs.append("-reverse")
    return cargs


def border_merge_select_params(
    border: str,
    up_to: BorderMergeUpToParameters | None = None,
) -> BorderMergeSelectParametersTagged:
    """
    Build parameters.
    
    Args:
        border: the border number or name.
        up_to: use an inclusive range of borders.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "select",
        "border": border,
    }
    if up_to is not None:
        params["up_to"] = up_to
    return params


def border_merge_select_cargs(
    params: BorderMergeSelectParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-select")
    cargs.append(params.get("border", None))
    if params.get("up_to", None) is not None:
        cargs.extend(border_merge_up_to_cargs(params.get("up_to", None), execution))
    return cargs


def border_merge_border_params(
    border_file_in: InputPathType,
    select_: list[BorderMergeSelectParameters] | None = None,
) -> BorderMergeBorderParametersTagged:
    """
    Build parameters.
    
    Args:
        border_file_in: a border file to use borders from.
        select_: select a single border to use.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "border",
        "border_file_in": border_file_in,
    }
    if select_ is not None:
        params["select"] = select_
    return params


def border_merge_border_cargs(
    params: BorderMergeBorderParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-border")
    cargs.append(execution.input_file(params.get("border_file_in", None)))
    if params.get("select", None) is not None:
        cargs.extend([a for c in [border_merge_select_cargs(s, execution) for s in params.get("select", None)] for a in c])
    return cargs


class BorderMergeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `BorderMergeParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    border_file_out: OutputPathType
    """the output border file"""


def border_merge_params(
    border_file_out: str,
    border: list[BorderMergeBorderParameters] | None = None,
) -> BorderMergeParametersTagged:
    """
    Build parameters.
    
    Args:
        border_file_out: the output border file.
        border: specify an input border file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/border-merge",
        "border_file_out": border_file_out,
    }
    if border is not None:
        params["border"] = border
    return params


def border_merge_cargs(
    params: BorderMergeParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-border-merge")
    cargs.append(params.get("border_file_out", None))
    if params.get("border", None) is not None:
        cargs.extend([a for c in [border_merge_border_cargs(s, execution) for s in params.get("border", None)] for a in c])
    return cargs


def border_merge_outputs(
    params: BorderMergeParameters,
    execution: Execution,
) -> BorderMergeOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = BorderMergeOutputs(
        root=execution.output_file("."),
        border_file_out=execution.output_file(params.get("border_file_out", None)),
    )
    return ret


def border_merge_execute(
    params: BorderMergeParameters,
    runner: Runner | None = None,
) -> BorderMergeOutputs:
    """
    border-merge
    
    Merge border files into a new file.
    
    Takes one or more border files and makes a new border file from the borders
    in them.
    
    Example: wb_command -border-merge out.border -border first.border -select 1
    -border second.border
    
    This example would take the first border from first.border, followed by all
    borders from second.border, and write these to out.border.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BorderMergeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BORDER_MERGE_METADATA)
    params = execution.params(params)
    cargs = border_merge_cargs(params, execution)
    ret = border_merge_outputs(params, execution)
    execution.run(cargs)
    return ret


def border_merge(
    border_file_out: str,
    border: list[BorderMergeBorderParameters] | None = None,
    runner: Runner | None = None,
) -> BorderMergeOutputs:
    """
    border-merge
    
    Merge border files into a new file.
    
    Takes one or more border files and makes a new border file from the borders
    in them.
    
    Example: wb_command -border-merge out.border -border first.border -select 1
    -border second.border
    
    This example would take the first border from first.border, followed by all
    borders from second.border, and write these to out.border.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        border_file_out: the output border file.
        border: specify an input border file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BorderMergeOutputs`).
    """
    params = border_merge_params(
        border_file_out=border_file_out,
        border=border,
    )
    return border_merge_execute(params, runner)


__all__ = [
    "BORDER_MERGE_METADATA",
    "BorderMergeOutputs",
    "border_merge",
    "border_merge_border_params",
    "border_merge_execute",
    "border_merge_params",
    "border_merge_select_params",
    "border_merge_up_to_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

METRIC_SMOOTHING_METADATA = Metadata(
    id="0a396b41d5717355e9d6de5fcc33e96e22014d30.boutiques",
    name="metric-smoothing",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


MetricSmoothingRoiParameters = typing.TypedDict('MetricSmoothingRoiParameters', {
    "@type": typing.NotRequired[typing.Literal["roi"]],
    "roi_metric": InputPathType,
    "opt_match_columns": bool,
})
MetricSmoothingRoiParametersTagged = typing.TypedDict('MetricSmoothingRoiParametersTagged', {
    "@type": typing.Literal["roi"],
    "roi_metric": InputPathType,
    "opt_match_columns": bool,
})


MetricSmoothingParameters = typing.TypedDict('MetricSmoothingParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/metric-smoothing"]],
    "surface": InputPathType,
    "metric_in": InputPathType,
    "smoothing_kernel": float,
    "metric_out": str,
    "opt_fwhm": bool,
    "roi": typing.NotRequired[MetricSmoothingRoiParameters | None],
    "opt_fix_zeros": bool,
    "opt_column_column": typing.NotRequired[str | None],
    "opt_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
    "opt_method_method": typing.NotRequired[str | None],
})
MetricSmoothingParametersTagged = typing.TypedDict('MetricSmoothingParametersTagged', {
    "@type": typing.Literal["workbench/metric-smoothing"],
    "surface": InputPathType,
    "metric_in": InputPathType,
    "smoothing_kernel": float,
    "metric_out": str,
    "opt_fwhm": bool,
    "roi": typing.NotRequired[MetricSmoothingRoiParameters | None],
    "opt_fix_zeros": bool,
    "opt_column_column": typing.NotRequired[str | None],
    "opt_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
    "opt_method_method": typing.NotRequired[str | None],
})


def metric_smoothing_roi_params(
    roi_metric: InputPathType,
    opt_match_columns: bool = False,
) -> MetricSmoothingRoiParametersTagged:
    """
    Build parameters.
    
    Args:
        roi_metric: the roi to smooth within, as a metric.
        opt_match_columns: for each input column, use the corresponding column\
            from the roi.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "roi",
        "roi_metric": roi_metric,
        "opt_match_columns": opt_match_columns,
    }
    return params


def metric_smoothing_roi_cargs(
    params: MetricSmoothingRoiParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-roi")
    cargs.append(execution.input_file(params.get("roi_metric", None)))
    if params.get("opt_match_columns", False):
        cargs.append("-match-columns")
    return cargs


class MetricSmoothingOutputs(typing.NamedTuple):
    """
    Output object returned when calling `MetricSmoothingParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric"""


def metric_smoothing_params(
    surface: InputPathType,
    metric_in: InputPathType,
    smoothing_kernel: float,
    metric_out: str,
    opt_fwhm: bool = False,
    roi: MetricSmoothingRoiParameters | None = None,
    opt_fix_zeros: bool = False,
    opt_column_column: str | None = None,
    opt_corrected_areas_area_metric: InputPathType | None = None,
    opt_method_method: str | None = None,
) -> MetricSmoothingParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: the surface to smooth on.
        metric_in: the metric to smooth.
        smoothing_kernel: the size of the gaussian smoothing kernel in mm, as\
            sigma by default.
        metric_out: the output metric.
        opt_fwhm: kernel size is FWHM, not sigma.
        roi: select a region of interest to smooth.
        opt_fix_zeros: treat zero values as not being data.
        opt_column_column: select a single column to smooth: the column number\
            or name.
        opt_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the surface: the corrected vertex areas, as a\
            metric.
        opt_method_method: select smoothing method, default GEO_GAUSS_AREA: the\
            name of the smoothing method.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/metric-smoothing",
        "surface": surface,
        "metric_in": metric_in,
        "smoothing_kernel": smoothing_kernel,
        "metric_out": metric_out,
        "opt_fwhm": opt_fwhm,
        "opt_fix_zeros": opt_fix_zeros,
    }
    if roi is not None:
        params["roi"] = roi
    if opt_column_column is not None:
        params["opt_column_column"] = opt_column_column
    if opt_corrected_areas_area_metric is not None:
        params["opt_corrected_areas_area_metric"] = opt_corrected_areas_area_metric
    if opt_method_method is not None:
        params["opt_method_method"] = opt_method_method
    return params


def metric_smoothing_cargs(
    params: MetricSmoothingParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-metric-smoothing")
    cargs.append(execution.input_file(params.get("surface", None)))
    cargs.append(execution.input_file(params.get("metric_in", None)))
    cargs.append(str(params.get("smoothing_kernel", None)))
    cargs.append(params.get("metric_out", None))
    if params.get("opt_fwhm", False):
        cargs.append("-fwhm")
    if params.get("roi", None) is not None:
        cargs.extend(metric_smoothing_roi_cargs(params.get("roi", None), execution))
    if params.get("opt_fix_zeros", False):
        cargs.append("-fix-zeros")
    if params.get("opt_column_column", None) is not None:
        cargs.extend([
            "-column",
            params.get("opt_column_column", None)
        ])
    if params.get("opt_corrected_areas_area_metric", None) is not None:
        cargs.extend([
            "-corrected-areas",
            execution.input_file(params.get("opt_corrected_areas_area_metric", None))
        ])
    if params.get("opt_method_method", None) is not None:
        cargs.extend([
            "-method",
            params.get("opt_method_method", None)
        ])
    return cargs


def metric_smoothing_outputs(
    params: MetricSmoothingParameters,
    execution: Execution,
) -> MetricSmoothingOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = MetricSmoothingOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(params.get("metric_out", None)),
    )
    return ret


def metric_smoothing_execute(
    params: MetricSmoothingParameters,
    runner: Runner | None = None,
) -> MetricSmoothingOutputs:
    """
    metric-smoothing
    
    Smooth a metric file.
    
    Smooth a metric file on a surface. By default, smooths all input columns on
    the entire surface, specify -column to use only one input column, and -roi
    to smooth only where the roi metric is greater than 0, outputting zeros
    elsewhere.
    
    When using -roi, input data outside the ROI is not used to compute the
    smoothed values. By default, the first column of the roi metric is used for
    all input columns. When -match-columns is specified to the -roi option, the
    input and roi metrics must have the same number of columns, and for each
    input column's index, the same column index is used in the roi metric. If
    the -match-columns option to -roi is used while the -column option is also
    used, the number of columns must match between the roi and input metric, and
    it will use the roi column with the index of the selected input column.
    
    The -fix-zeros option causes the smoothing to not use an input value if it
    is zero, but still write a smoothed value to the vertex. This is useful for
    zeros that indicate lack of information, preventing them from pulling down
    the intensity of nearby vertices, while giving the zero an extrapolated
    value.
    
    The -corrected-areas option is intended for when it is unavoidable to smooth
    on a group average surface, it is only an approximate correction for the
    reduction of structure in a group average surface. It is better to smooth
    the data on individuals before averaging, when feasible.
    
    Valid values for <method> are:
    
    GEO_GAUSS_AREA - uses a geodesic gaussian kernel, and normalizes based on
    vertex area in order to work more reliably on irregular surfaces
    
    GEO_GAUSS_EQUAL - uses a geodesic gaussian kernel, and normalizes assuming
    each vertex has equal importance
    
    GEO_GAUSS - matches geodesic gaussian smoothing from caret5, but does not
    check kernels for having unequal importance
    
    The GEO_GAUSS_AREA method is the default because it is usually the correct
    choice. GEO_GAUSS_EQUAL may be the correct choice when the sum of vertex
    values is more meaningful then the surface integral (sum of values .*
    areas), for instance when smoothing vertex areas (the sum is the total
    surface area, while the surface integral is the sum of squares of the vertex
    areas). The GEO_GAUSS method is not recommended, it exists mainly to
    replicate methods of studies done with caret5's geodesic smoothing.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricSmoothingOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(METRIC_SMOOTHING_METADATA)
    params = execution.params(params)
    cargs = metric_smoothing_cargs(params, execution)
    ret = metric_smoothing_outputs(params, execution)
    execution.run(cargs)
    return ret


def metric_smoothing(
    surface: InputPathType,
    metric_in: InputPathType,
    smoothing_kernel: float,
    metric_out: str,
    opt_fwhm: bool = False,
    roi: MetricSmoothingRoiParameters | None = None,
    opt_fix_zeros: bool = False,
    opt_column_column: str | None = None,
    opt_corrected_areas_area_metric: InputPathType | None = None,
    opt_method_method: str | None = None,
    runner: Runner | None = None,
) -> MetricSmoothingOutputs:
    """
    metric-smoothing
    
    Smooth a metric file.
    
    Smooth a metric file on a surface. By default, smooths all input columns on
    the entire surface, specify -column to use only one input column, and -roi
    to smooth only where the roi metric is greater than 0, outputting zeros
    elsewhere.
    
    When using -roi, input data outside the ROI is not used to compute the
    smoothed values. By default, the first column of the roi metric is used for
    all input columns. When -match-columns is specified to the -roi option, the
    input and roi metrics must have the same number of columns, and for each
    input column's index, the same column index is used in the roi metric. If
    the -match-columns option to -roi is used while the -column option is also
    used, the number of columns must match between the roi and input metric, and
    it will use the roi column with the index of the selected input column.
    
    The -fix-zeros option causes the smoothing to not use an input value if it
    is zero, but still write a smoothed value to the vertex. This is useful for
    zeros that indicate lack of information, preventing them from pulling down
    the intensity of nearby vertices, while giving the zero an extrapolated
    value.
    
    The -corrected-areas option is intended for when it is unavoidable to smooth
    on a group average surface, it is only an approximate correction for the
    reduction of structure in a group average surface. It is better to smooth
    the data on individuals before averaging, when feasible.
    
    Valid values for <method> are:
    
    GEO_GAUSS_AREA - uses a geodesic gaussian kernel, and normalizes based on
    vertex area in order to work more reliably on irregular surfaces
    
    GEO_GAUSS_EQUAL - uses a geodesic gaussian kernel, and normalizes assuming
    each vertex has equal importance
    
    GEO_GAUSS - matches geodesic gaussian smoothing from caret5, but does not
    check kernels for having unequal importance
    
    The GEO_GAUSS_AREA method is the default because it is usually the correct
    choice. GEO_GAUSS_EQUAL may be the correct choice when the sum of vertex
    values is more meaningful then the surface integral (sum of values .*
    areas), for instance when smoothing vertex areas (the sum is the total
    surface area, while the surface integral is the sum of squares of the vertex
    areas). The GEO_GAUSS method is not recommended, it exists mainly to
    replicate methods of studies done with caret5's geodesic smoothing.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface: the surface to smooth on.
        metric_in: the metric to smooth.
        smoothing_kernel: the size of the gaussian smoothing kernel in mm, as\
            sigma by default.
        metric_out: the output metric.
        opt_fwhm: kernel size is FWHM, not sigma.
        roi: select a region of interest to smooth.
        opt_fix_zeros: treat zero values as not being data.
        opt_column_column: select a single column to smooth: the column number\
            or name.
        opt_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the surface: the corrected vertex areas, as a\
            metric.
        opt_method_method: select smoothing method, default GEO_GAUSS_AREA: the\
            name of the smoothing method.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricSmoothingOutputs`).
    """
    params = metric_smoothing_params(
        surface=surface,
        metric_in=metric_in,
        smoothing_kernel=smoothing_kernel,
        metric_out=metric_out,
        opt_fwhm=opt_fwhm,
        roi=roi,
        opt_fix_zeros=opt_fix_zeros,
        opt_column_column=opt_column_column,
        opt_corrected_areas_area_metric=opt_corrected_areas_area_metric,
        opt_method_method=opt_method_method,
    )
    return metric_smoothing_execute(params, runner)


__all__ = [
    "METRIC_SMOOTHING_METADATA",
    "MetricSmoothingOutputs",
    "metric_smoothing",
    "metric_smoothing_execute",
    "metric_smoothing_params",
    "metric_smoothing_roi_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CONVERT_MATRIX4_TO_WORKBENCH_SPARSE_METADATA = Metadata(
    id="9de14d1819ec9b8a462cc20406cc4824564bd8e3.boutiques",
    name="convert-matrix4-to-workbench-sparse",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


ConvertMatrix4ToWorkbenchSparseVolumeSeedsParameters = typing.TypedDict('ConvertMatrix4ToWorkbenchSparseVolumeSeedsParameters', {
    "@type": typing.NotRequired[typing.Literal["volume_seeds"]],
    "cifti_template": InputPathType,
    "direction": str,
})
ConvertMatrix4ToWorkbenchSparseVolumeSeedsParametersTagged = typing.TypedDict('ConvertMatrix4ToWorkbenchSparseVolumeSeedsParametersTagged', {
    "@type": typing.Literal["volume_seeds"],
    "cifti_template": InputPathType,
    "direction": str,
})


ConvertMatrix4ToWorkbenchSparseParameters = typing.TypedDict('ConvertMatrix4ToWorkbenchSparseParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/convert-matrix4-to-workbench-sparse"]],
    "matrix4_1": str,
    "matrix4_2": str,
    "matrix4_3": str,
    "orientation_file": InputPathType,
    "voxel_list": str,
    "wb_sparse_out": str,
    "opt_surface_seeds_seed_roi": typing.NotRequired[InputPathType | None],
    "volume_seeds": typing.NotRequired[ConvertMatrix4ToWorkbenchSparseVolumeSeedsParameters | None],
})
ConvertMatrix4ToWorkbenchSparseParametersTagged = typing.TypedDict('ConvertMatrix4ToWorkbenchSparseParametersTagged', {
    "@type": typing.Literal["workbench/convert-matrix4-to-workbench-sparse"],
    "matrix4_1": str,
    "matrix4_2": str,
    "matrix4_3": str,
    "orientation_file": InputPathType,
    "voxel_list": str,
    "wb_sparse_out": str,
    "opt_surface_seeds_seed_roi": typing.NotRequired[InputPathType | None],
    "volume_seeds": typing.NotRequired[ConvertMatrix4ToWorkbenchSparseVolumeSeedsParameters | None],
})


def convert_matrix4_to_workbench_sparse_volume_seeds_params(
    cifti_template: InputPathType,
    direction: str,
) -> ConvertMatrix4ToWorkbenchSparseVolumeSeedsParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti_template: cifti file to use the volume mappings from.
        direction: dimension along the cifti file to take the mapping from, ROW\
            or COLUMN.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "volume_seeds",
        "cifti_template": cifti_template,
        "direction": direction,
    }
    return params


def convert_matrix4_to_workbench_sparse_volume_seeds_cargs(
    params: ConvertMatrix4ToWorkbenchSparseVolumeSeedsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-volume-seeds")
    cargs.append(execution.input_file(params.get("cifti_template", None)))
    cargs.append(params.get("direction", None))
    return cargs


class ConvertMatrix4ToWorkbenchSparseOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ConvertMatrix4ToWorkbenchSparseParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def convert_matrix4_to_workbench_sparse_params(
    matrix4_1: str,
    matrix4_2: str,
    matrix4_3: str,
    orientation_file: InputPathType,
    voxel_list: str,
    wb_sparse_out: str,
    opt_surface_seeds_seed_roi: InputPathType | None = None,
    volume_seeds: ConvertMatrix4ToWorkbenchSparseVolumeSeedsParameters | None = None,
) -> ConvertMatrix4ToWorkbenchSparseParametersTagged:
    """
    Build parameters.
    
    Args:
        matrix4_1: the first matrix4 file.
        matrix4_2: the second matrix4 file.
        matrix4_3: the third matrix4 file.
        orientation_file: the .fiberTEMP.nii file this trajectory file applies\
            to.
        voxel_list: list of white matter voxel index triplets as used in the\
            trajectory matrix.
        wb_sparse_out: output - the output workbench sparse file.
        opt_surface_seeds_seed_roi: specify the surface seed space: metric roi\
            file of all vertices used in the seed space.
        volume_seeds: specify the volume seed space.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/convert-matrix4-to-workbench-sparse",
        "matrix4_1": matrix4_1,
        "matrix4_2": matrix4_2,
        "matrix4_3": matrix4_3,
        "orientation_file": orientation_file,
        "voxel_list": voxel_list,
        "wb_sparse_out": wb_sparse_out,
    }
    if opt_surface_seeds_seed_roi is not None:
        params["opt_surface_seeds_seed_roi"] = opt_surface_seeds_seed_roi
    if volume_seeds is not None:
        params["volume_seeds"] = volume_seeds
    return params


def convert_matrix4_to_workbench_sparse_cargs(
    params: ConvertMatrix4ToWorkbenchSparseParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-convert-matrix4-to-workbench-sparse")
    cargs.append(params.get("matrix4_1", None))
    cargs.append(params.get("matrix4_2", None))
    cargs.append(params.get("matrix4_3", None))
    cargs.append(execution.input_file(params.get("orientation_file", None)))
    cargs.append(params.get("voxel_list", None))
    cargs.append(params.get("wb_sparse_out", None))
    if params.get("opt_surface_seeds_seed_roi", None) is not None:
        cargs.extend([
            "-surface-seeds",
            execution.input_file(params.get("opt_surface_seeds_seed_roi", None))
        ])
    if params.get("volume_seeds", None) is not None:
        cargs.extend(convert_matrix4_to_workbench_sparse_volume_seeds_cargs(params.get("volume_seeds", None), execution))
    return cargs


def convert_matrix4_to_workbench_sparse_outputs(
    params: ConvertMatrix4ToWorkbenchSparseParameters,
    execution: Execution,
) -> ConvertMatrix4ToWorkbenchSparseOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = ConvertMatrix4ToWorkbenchSparseOutputs(
        root=execution.output_file("."),
    )
    return ret


def convert_matrix4_to_workbench_sparse_execute(
    params: ConvertMatrix4ToWorkbenchSparseParameters,
    runner: Runner | None = None,
) -> ConvertMatrix4ToWorkbenchSparseOutputs:
    """
    convert-matrix4-to-workbench-sparse
    
    Convert a 3-file matrix4 to a workbench sparse file.
    
    Converts the matrix 4 output of probtrackx to workbench sparse file format.
    Exactly one of -surface-seeds and -volume-seeds must be specified.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ConvertMatrix4ToWorkbenchSparseOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CONVERT_MATRIX4_TO_WORKBENCH_SPARSE_METADATA)
    params = execution.params(params)
    cargs = convert_matrix4_to_workbench_sparse_cargs(params, execution)
    ret = convert_matrix4_to_workbench_sparse_outputs(params, execution)
    execution.run(cargs)
    return ret


def convert_matrix4_to_workbench_sparse(
    matrix4_1: str,
    matrix4_2: str,
    matrix4_3: str,
    orientation_file: InputPathType,
    voxel_list: str,
    wb_sparse_out: str,
    opt_surface_seeds_seed_roi: InputPathType | None = None,
    volume_seeds: ConvertMatrix4ToWorkbenchSparseVolumeSeedsParameters | None = None,
    runner: Runner | None = None,
) -> ConvertMatrix4ToWorkbenchSparseOutputs:
    """
    convert-matrix4-to-workbench-sparse
    
    Convert a 3-file matrix4 to a workbench sparse file.
    
    Converts the matrix 4 output of probtrackx to workbench sparse file format.
    Exactly one of -surface-seeds and -volume-seeds must be specified.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        matrix4_1: the first matrix4 file.
        matrix4_2: the second matrix4 file.
        matrix4_3: the third matrix4 file.
        orientation_file: the .fiberTEMP.nii file this trajectory file applies\
            to.
        voxel_list: list of white matter voxel index triplets as used in the\
            trajectory matrix.
        wb_sparse_out: output - the output workbench sparse file.
        opt_surface_seeds_seed_roi: specify the surface seed space: metric roi\
            file of all vertices used in the seed space.
        volume_seeds: specify the volume seed space.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ConvertMatrix4ToWorkbenchSparseOutputs`).
    """
    params = convert_matrix4_to_workbench_sparse_params(
        matrix4_1=matrix4_1,
        matrix4_2=matrix4_2,
        matrix4_3=matrix4_3,
        orientation_file=orientation_file,
        voxel_list=voxel_list,
        wb_sparse_out=wb_sparse_out,
        opt_surface_seeds_seed_roi=opt_surface_seeds_seed_roi,
        volume_seeds=volume_seeds,
    )
    return convert_matrix4_to_workbench_sparse_execute(params, runner)


__all__ = [
    "CONVERT_MATRIX4_TO_WORKBENCH_SPARSE_METADATA",
    "ConvertMatrix4ToWorkbenchSparseOutputs",
    "convert_matrix4_to_workbench_sparse",
    "convert_matrix4_to_workbench_sparse_execute",
    "convert_matrix4_to_workbench_sparse_params",
    "convert_matrix4_to_workbench_sparse_volume_seeds_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SURFACE_CURVATURE_METADATA = Metadata(
    id="959b1a4fb2add4507cd3f4cc23eb187ef2dc3681.boutiques",
    name="surface-curvature",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SurfaceCurvatureParameters = typing.TypedDict('SurfaceCurvatureParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/surface-curvature"]],
    "surface": InputPathType,
    "opt_mean_mean_out": typing.NotRequired[str | None],
    "opt_gauss_gauss_out": typing.NotRequired[str | None],
})
SurfaceCurvatureParametersTagged = typing.TypedDict('SurfaceCurvatureParametersTagged', {
    "@type": typing.Literal["workbench/surface-curvature"],
    "surface": InputPathType,
    "opt_mean_mean_out": typing.NotRequired[str | None],
    "opt_gauss_gauss_out": typing.NotRequired[str | None],
})


class SurfaceCurvatureOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SurfaceCurvatureParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    opt_mean_mean_out: OutputPathType | None
    """output mean curvature: mean curvature metric"""
    opt_gauss_gauss_out: OutputPathType | None
    """output gaussian curvature: gaussian curvature metric"""


def surface_curvature_params(
    surface: InputPathType,
    opt_mean_mean_out: str | None = None,
    opt_gauss_gauss_out: str | None = None,
) -> SurfaceCurvatureParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: the surface to compute the curvature of.
        opt_mean_mean_out: output mean curvature: mean curvature metric.
        opt_gauss_gauss_out: output gaussian curvature: gaussian curvature\
            metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/surface-curvature",
        "surface": surface,
    }
    if opt_mean_mean_out is not None:
        params["opt_mean_mean_out"] = opt_mean_mean_out
    if opt_gauss_gauss_out is not None:
        params["opt_gauss_gauss_out"] = opt_gauss_gauss_out
    return params


def surface_curvature_cargs(
    params: SurfaceCurvatureParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-curvature")
    cargs.append(execution.input_file(params.get("surface", None)))
    if params.get("opt_mean_mean_out", None) is not None:
        cargs.extend([
            "-mean",
            params.get("opt_mean_mean_out", None)
        ])
    if params.get("opt_gauss_gauss_out", None) is not None:
        cargs.extend([
            "-gauss",
            params.get("opt_gauss_gauss_out", None)
        ])
    return cargs


def surface_curvature_outputs(
    params: SurfaceCurvatureParameters,
    execution: Execution,
) -> SurfaceCurvatureOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SurfaceCurvatureOutputs(
        root=execution.output_file("."),
        opt_mean_mean_out=execution.output_file(params.get("opt_mean_mean_out", None)) if (params.get("opt_mean_mean_out") is not None) else None,
        opt_gauss_gauss_out=execution.output_file(params.get("opt_gauss_gauss_out", None)) if (params.get("opt_gauss_gauss_out") is not None) else None,
    )
    return ret


def surface_curvature_execute(
    params: SurfaceCurvatureParameters,
    runner: Runner | None = None,
) -> SurfaceCurvatureOutputs:
    """
    surface-curvature
    
    Calculate curvature of surface.
    
    Compute the curvature of the surface, using the method from:
    Interactive Texture Mapping by J. Maillot, Yahia, and Verroust, 1993.
    ACM-0-98791-601-8/93/008.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceCurvatureOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_CURVATURE_METADATA)
    params = execution.params(params)
    cargs = surface_curvature_cargs(params, execution)
    ret = surface_curvature_outputs(params, execution)
    execution.run(cargs)
    return ret


def surface_curvature(
    surface: InputPathType,
    opt_mean_mean_out: str | None = None,
    opt_gauss_gauss_out: str | None = None,
    runner: Runner | None = None,
) -> SurfaceCurvatureOutputs:
    """
    surface-curvature
    
    Calculate curvature of surface.
    
    Compute the curvature of the surface, using the method from:
    Interactive Texture Mapping by J. Maillot, Yahia, and Verroust, 1993.
    ACM-0-98791-601-8/93/008.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface: the surface to compute the curvature of.
        opt_mean_mean_out: output mean curvature: mean curvature metric.
        opt_gauss_gauss_out: output gaussian curvature: gaussian curvature\
            metric.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceCurvatureOutputs`).
    """
    params = surface_curvature_params(
        surface=surface,
        opt_mean_mean_out=opt_mean_mean_out,
        opt_gauss_gauss_out=opt_gauss_gauss_out,
    )
    return surface_curvature_execute(params, runner)


__all__ = [
    "SURFACE_CURVATURE_METADATA",
    "SurfaceCurvatureOutputs",
    "surface_curvature",
    "surface_curvature_execute",
    "surface_curvature_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_ESTIMATE_FWHM_METADATA = Metadata(
    id="406da450dd413b66fe869bedf1e3287559817350.boutiques",
    name="cifti-estimate-fwhm",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiEstimateFwhmWholeFileParameters = typing.TypedDict('CiftiEstimateFwhmWholeFileParameters', {
    "@type": typing.NotRequired[typing.Literal["whole_file"]],
    "opt_demean": bool,
})
CiftiEstimateFwhmWholeFileParametersTagged = typing.TypedDict('CiftiEstimateFwhmWholeFileParametersTagged', {
    "@type": typing.Literal["whole_file"],
    "opt_demean": bool,
})


CiftiEstimateFwhmSurfaceParameters = typing.TypedDict('CiftiEstimateFwhmSurfaceParameters', {
    "@type": typing.NotRequired[typing.Literal["surface"]],
    "structure": str,
    "surface": InputPathType,
})
CiftiEstimateFwhmSurfaceParametersTagged = typing.TypedDict('CiftiEstimateFwhmSurfaceParametersTagged', {
    "@type": typing.Literal["surface"],
    "structure": str,
    "surface": InputPathType,
})


CiftiEstimateFwhmParameters = typing.TypedDict('CiftiEstimateFwhmParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-estimate-fwhm"]],
    "cifti": InputPathType,
    "opt_merged_volume": bool,
    "opt_column_column": typing.NotRequired[int | None],
    "whole_file": typing.NotRequired[CiftiEstimateFwhmWholeFileParameters | None],
    "surface": typing.NotRequired[list[CiftiEstimateFwhmSurfaceParameters] | None],
})
CiftiEstimateFwhmParametersTagged = typing.TypedDict('CiftiEstimateFwhmParametersTagged', {
    "@type": typing.Literal["workbench/cifti-estimate-fwhm"],
    "cifti": InputPathType,
    "opt_merged_volume": bool,
    "opt_column_column": typing.NotRequired[int | None],
    "whole_file": typing.NotRequired[CiftiEstimateFwhmWholeFileParameters | None],
    "surface": typing.NotRequired[list[CiftiEstimateFwhmSurfaceParameters] | None],
})


def cifti_estimate_fwhm_whole_file_params(
    opt_demean: bool = False,
) -> CiftiEstimateFwhmWholeFileParametersTagged:
    """
    Build parameters.
    
    Args:
        opt_demean: subtract the mean image before estimating smoothness.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "whole_file",
        "opt_demean": opt_demean,
    }
    return params


def cifti_estimate_fwhm_whole_file_cargs(
    params: CiftiEstimateFwhmWholeFileParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-whole-file")
    if params.get("opt_demean", False):
        cargs.append("-demean")
    return cargs


def cifti_estimate_fwhm_surface_params(
    structure: str,
    surface: InputPathType,
) -> CiftiEstimateFwhmSurfaceParametersTagged:
    """
    Build parameters.
    
    Args:
        structure: what structure to use this surface for.
        surface: the surface file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "surface",
        "structure": structure,
        "surface": surface,
    }
    return params


def cifti_estimate_fwhm_surface_cargs(
    params: CiftiEstimateFwhmSurfaceParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-surface")
    cargs.append(params.get("structure", None))
    cargs.append(execution.input_file(params.get("surface", None)))
    return cargs


class CiftiEstimateFwhmOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiEstimateFwhmParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def cifti_estimate_fwhm_params(
    cifti: InputPathType,
    opt_merged_volume: bool = False,
    opt_column_column: int | None = None,
    whole_file: CiftiEstimateFwhmWholeFileParameters | None = None,
    surface: list[CiftiEstimateFwhmSurfaceParameters] | None = None,
) -> CiftiEstimateFwhmParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti: the input cifti file.
        opt_merged_volume: treat volume components as if they were a single\
            component.
        opt_column_column: only output estimates for one column: the column\
            number.
        whole_file: estimate for the whole file at once, not each column\
            separately.
        surface: specify an input surface.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-estimate-fwhm",
        "cifti": cifti,
        "opt_merged_volume": opt_merged_volume,
    }
    if opt_column_column is not None:
        params["opt_column_column"] = opt_column_column
    if whole_file is not None:
        params["whole_file"] = whole_file
    if surface is not None:
        params["surface"] = surface
    return params


def cifti_estimate_fwhm_cargs(
    params: CiftiEstimateFwhmParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-estimate-fwhm")
    cargs.append(execution.input_file(params.get("cifti", None)))
    if params.get("opt_merged_volume", False):
        cargs.append("-merged-volume")
    if params.get("opt_column_column", None) is not None:
        cargs.extend([
            "-column",
            str(params.get("opt_column_column", None))
        ])
    if params.get("whole_file", None) is not None:
        cargs.extend(cifti_estimate_fwhm_whole_file_cargs(params.get("whole_file", None), execution))
    if params.get("surface", None) is not None:
        cargs.extend([a for c in [cifti_estimate_fwhm_surface_cargs(s, execution) for s in params.get("surface", None)] for a in c])
    return cargs


def cifti_estimate_fwhm_outputs(
    params: CiftiEstimateFwhmParameters,
    execution: Execution,
) -> CiftiEstimateFwhmOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiEstimateFwhmOutputs(
        root=execution.output_file("."),
    )
    return ret


def cifti_estimate_fwhm_execute(
    params: CiftiEstimateFwhmParameters,
    runner: Runner | None = None,
) -> CiftiEstimateFwhmOutputs:
    """
    cifti-estimate-fwhm
    
    Estimate fwhm smoothness of a cifti file.
    
    Estimate the smoothness of the components of the cifti file, printing the
    estimates to standard output. If -merged-volume is used, all voxels are used
    as a single component, rather than separated by structure.
    
    <structure> must be one of the following:
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiEstimateFwhmOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_ESTIMATE_FWHM_METADATA)
    params = execution.params(params)
    cargs = cifti_estimate_fwhm_cargs(params, execution)
    ret = cifti_estimate_fwhm_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_estimate_fwhm(
    cifti: InputPathType,
    opt_merged_volume: bool = False,
    opt_column_column: int | None = None,
    whole_file: CiftiEstimateFwhmWholeFileParameters | None = None,
    surface: list[CiftiEstimateFwhmSurfaceParameters] | None = None,
    runner: Runner | None = None,
) -> CiftiEstimateFwhmOutputs:
    """
    cifti-estimate-fwhm
    
    Estimate fwhm smoothness of a cifti file.
    
    Estimate the smoothness of the components of the cifti file, printing the
    estimates to standard output. If -merged-volume is used, all voxels are used
    as a single component, rather than separated by structure.
    
    <structure> must be one of the following:
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti: the input cifti file.
        opt_merged_volume: treat volume components as if they were a single\
            component.
        opt_column_column: only output estimates for one column: the column\
            number.
        whole_file: estimate for the whole file at once, not each column\
            separately.
        surface: specify an input surface.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiEstimateFwhmOutputs`).
    """
    params = cifti_estimate_fwhm_params(
        cifti=cifti,
        opt_merged_volume=opt_merged_volume,
        opt_column_column=opt_column_column,
        whole_file=whole_file,
        surface=surface,
    )
    return cifti_estimate_fwhm_execute(params, runner)


__all__ = [
    "CIFTI_ESTIMATE_FWHM_METADATA",
    "CiftiEstimateFwhmOutputs",
    "cifti_estimate_fwhm",
    "cifti_estimate_fwhm_execute",
    "cifti_estimate_fwhm_params",
    "cifti_estimate_fwhm_surface_params",
    "cifti_estimate_fwhm_whole_file_params",
]
